function [u2,mtf50,r,LSF,PSF,f,mtfSys] = DOFthruMTF(fn,N,u,W40,MTFth,n,pitch,ff,lambda)
    %Calculates monochromatic Depth Of Field given nominal lens focal length
    %fn (mm) and f-number N, in-focus distance u (m), Seidel 3rd order 
    %Spherical Aberration W40 Optical Path Ddifference p-v (um), MTF50 
    %'acceptably in-focus' threshold in lp/mm, light wavelength lambda
    %(um), n is the power of 2 number of pix in LSF (physical r in um)
    %sensor pitch (um), linear fill factor ff and wavelength lambda (um)
    %Assumes 'best RMS focus' occurs with W020=-W040. Spatial freq f in lp/um.
    %EXAMPLE: [u2,mtf50] = DOFthruMTF(50,2.8,10,1.117*0.535);
    %By Jack Hogan  - Version 0.31 - Refer to:
    %www.strollswithmydog.com/dof-diffraction-setup/
    
    if nargin < 9
        lambda = 0.535;                         %um, light wavelength
        if nargin < 8
            ff = 0.866;                         %Z7 linear fill factor
            if nargin < 7
                pitch = 4.33;                   %um, pixel pitch for MTF
                if nargin < 6
                    n = 1024;                   %< is faster, watch ringing
                    if nargin < 5
                        MTFth = 50;             %lp/mm, MTF50 in-focus threshold
                        if nargin < 4
                            W40 = 0;            %no SA3
                        end
                    end
                end
            end
        end
    end
    %% LSF and MTF at each distance u2
    Q = 9;                                      %D padding/PSF sampling factor
    wAxis =(-0.5:1/n:0.5-1/n) *2*Q;             %radii, QD in total
    [U,V] = meshgrid(wAxis);                    %radii, 2D pupil coords
    RHO = sqrt(U.^2 + V.^2);                    %radii, distance from axis
    RHO2 = RHO.^2;                              %makes things a bit faster
    stop = RHO>1;                               %circular aperture stop
    
    D = fn/N/1000;                              %m, aperture diameter
    fz = 1/(1/u+1000/fn) + W40*8*N^2/10^6;      %m, sensing plane distance
    Nz = fz / D;                                %N at RMS 'best focus'
    r = (-n/2:n/2-1) / Q * lambda*Nz;           %um, LSF V coords
    f = (0:1/n:1-1/n)' * Q / lambda/Nz;         %cycles per um, V MTF freq.
    
    u2 = (0.7:1/30:1.3)*u;
    W2 = -(sqrt(u^2-D^2/4) - sqrt(u2.^2-D^2/4) - (u - u2)) * 10^6; %um
    
    jk = 1i*2*pi/lambda;                        %wave number, complex
    wf = exp( jk * W40*(RHO.^4-RHO2) );         %fixed, best 'focus'
    
    LSF = zeros(n,length(u2));                  %object side
    PSF = zeros(n,n,length(u2));
    tic
    for i = 1:length(u2)                        %for every plane:
        w = wf .* exp(jk .* W2(i) .* RHO2);     %wavefront at exit pupil
        w(stop) = 0;                            %circular aperture
        
        psf = fftshift(fft2(w));                %diffracted amplitude
        PSF(:,:,i) = psf .* conj(psf);          %intensity = |FT|^2
        LSF(:,i) = sum(PSF(:,:,i));             %LSF at this distance
        
        figure
        imagesc(r,r,PSF(:,:,i).^0.45)
        axis equal; colormap('gray')
        xlim([-15 15]); ylim([-15 15])
        
    end
    toc
    PSF = PSF / max(max(max(PSF)));
    LSF = LSF / max(LSF(:));                    %normalized to max intensity
        
    mtfLens = abs(fft(LSF));                    %MTF of lens in V direction
    mtfLens = mtfLens ./ max(mtfLens);          %normalize all to 1 at origin
    
    
    %% System MTF curve
    mtfPix = abs(sin(pi*f*pitch*ff)./(pi*f*pitch*ff));
    mtfPix(1) = 1;
    mtfSys = mtfLens .* mtfPix;                 %convolve with pixel aperture
    
    mtf50 = zeros(1,length(u2));
    for i  = 1:length(u2)                       %MTF50 at each plane
        mtf = mtfSys(:,i);
        I = find(mtf < 0.5, 1);                 %to deal with non monotonicity
        mtf50(i) = interp1(mtf(1:I),f(1:I),0.5);%lp/um
    end
    
end